User Configuration — PyRemoteData 0.0.48 documentation

Skip to content

# User Configuration

pyremotedata.config.ask_user(question, interactive=True)

pyremotedata.config.create_default_config(interactive=True)

pyremotedata.config.deparse_args(config, what)

pyremotedata.config.get_config(validate: bool = True)

pyremotedata.config.get_dataloader_config(**kwargs)

pyremotedata.config.get_environment_variables(interactive=True)

pyremotedata.config.get_implicit_mount_config(**kwargs)

pyremotedata.config.get_mount_config(**kwargs)

pyremotedata.config.get_this_config(this, **kwargs)

pyremotedata.config.remove_config()